"use client";
import { FC, PropsWithChildren } from "react";
import { useRouter } from "@/i18n";
import clsx from "clsx";
import ItemCom from "./component/ItemCom";
import './page.scss'
import { useGlobalStore } from '@/stores';
import {getLogoutApi} from "@/api/user";

interface Props {}

const Profile: FC<PropsWithChildren<Props>> = () => {
    const { token, setToken, userInfo, setUserInfo } = useGlobalStore();

    const logoutRequest = async () => {
        let res = await getLogoutApi()
        if(res.code == 200) {
            setUserInfo('')
            setToken('')
            router.replace('/login')
        }
    }

    const router = useRouter();
    const goPage = (path = '/') => {
        router.push(path)
    }

    const divClassName = clsx('bgImg', token && 'default');
    return (
        <div className="profile-box">
            <div className="userContent">
                <div className="userInfo">
                    <div>
                        <div className={divClassName}></div>
                        {
                            token && (
                                <div>
                                    <span>{userInfo?.user_name || '昵称'}</span>
                                    <span className="phone">{userInfo?.user_phone || ''}</span>
                                </div>
                            )
                        }
                    </div>
                    <div className="goto" onClick={() => goPage('/login')}>
                        { !token && <span>Login</span> }
                        <span className="iconfont icon-xiangzuo1"></span>
                    </div>
                </div>
                { 
                    token && (
                        <div className="coin">
                            <div>
                                <span className="iconfont icon-icon-wallet"></span>
                                <div>
                                    <span> Saldo </span>
                                    <div className="num">
                                        <span className="uppercase">brl </span>
                                        <span>0.00</span>
                                    </div>
                                </div>
                            </div>
                            <div>
                                <span className="iconfont icon-gift2"></span>
                                <div>
                                    <span> Bônus <img className="a" src="/img/a.png" alt="" /></span>
                                    <div className="num">
                                        <span className="uppercase">brl </span>
                                        <span>0.00</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    ) 
                }
            </div>

            <div className="link">
                <span  onClick={() => goPage('/deposit')}>Depósito</span>
                <span  onClick={() => goPage(token ? '/withdraw' : `/login?redirect=withdraw`)}>Sacar</span>
            </div>

            <ItemCom />

            {
                token ? <span className="logOut" onClick={logoutRequest}>Sair</span> : (
                    <span className="logOut" onClick={() => goPage('/login')}>Login</span>
                )
            }
        </div>
    );
};

export default Profile;
